Parents and Elements
====================

Sage Objects
------------

.. toctree::
   :maxdepth: 1

   sage/structure/sage_object
   sage/structure/category_object

Parents
-------

Parents
~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/structure/parent
   sage/structure/indexed_generators
   sage/structure/nonexact
   sage/structure/global_options

Old-Style Parents (Deprecated)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/structure/parent_old
   sage/structure/parent_base
   sage/structure/parent_gens
   sage/structure/gens_py

Elements
--------

.. toctree::
   :maxdepth: 1

   sage/structure/element
   sage/structure/element_wrapper
   sage/structure/list_clone
   sage/structure/list_clone_demo

Mathematical Data Structures
----------------------------

.. toctree::
   :maxdepth: 1

   sage/structure/formal_sum
   sage/structure/factorization
   sage/structure/factorization_integer
   sage/structure/sequence
   sage/structure/set_factories
   sage/structure/set_factories_example

Use of Heuristic and Probabilistic Algorithms
---------------------------------------------

.. toctree::
   :maxdepth: 1

   sage/structure/proof/proof
   sage/misc/proof

Utilities
---------

.. toctree::
   :maxdepth: 1

   sage/structure/richcmp
   sage/structure/unique_representation
   sage/structure/factory
   sage/structure/dynamic_class
   sage/structure/mutability

Internals
---------

.. toctree::
   :maxdepth: 1

   sage/structure/debug_options
   sage/structure/list_clone_timings
   sage/structure/list_clone_timings_cy
   sage/structure/test_factory

.. include:: ../footer.txt
